<?php

/**
 * @file
 * The Track Field Changes Admin.
 */

/**
 * Menu callback; prints a listing of active nodes on the site.
 */
function track_field_changes_admin_settings() {

  // When displaying the page, make sure the list of fields is up-to-date.
  field_info_cache_clear();

  $form = array();

  $form['settings'] = array(
    '#type' => 'vertical_tabs',
  );

  $form['track_field_changes'] = array(
    '#type' => 'fieldset',
    '#title'       => t('Content Type'),
    '#group'       => 'settings',
  );

  // Gather node type information.
  $node_types = node_type_get_names();

  $form['track_field_changes']['track_field_changes_node_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Enable field audit on content types.'),
    '#description' => t('Enable field audit on content types.'),
    '#default_value' => variable_get('track_field_changes_node_types', array()),
    '#options' => $node_types,
  );

  $types = variable_get('track_field_changes_node_types', array());

  foreach ($types as $key => $type) {

    if ($type) {
      $form['track_field_changes_' . $key] = array(
        '#type' => 'fieldset',
        '#title' => $node_types[$key],
        '#group'       => 'settings',
      );

      $fields = field_info_instances('node', $key);

      $selected_fields = track_field_changes_get_selected_field($key);

      $options = NULL;
      $options['title'] = t('Title');

      foreach ($fields as $field) {

        $field_info_field = field_info_field($field['field_name']);

        $options[$field['field_name']] = $field['label'];
      }

      $form['track_field_changes_' . $key]['enable_log'] = array(
        '#type' => 'checkboxe',
        '#title' => t('Enable log.'),
        '#description' => t('Enable log.'),
      );

      $form['track_field_changes_' . $key]['track_field_changes_fields'][$key] = array(
        '#type' => 'checkboxes',
        '#title' => t('Enable field audit on content types.'),
        '#description' => t('Enable field audit on content types.'),
        '#default_value' => $selected_fields,
        '#options' => $options,
      );

    };
  }

  $form['#submit'][] = 'track_field_changes_admin_settings_submit';

  return system_settings_form($form);

}

/**
 * Save track field settings.
 */
function track_field_changes_admin_settings_submit($form, &$form_state) {

  // Delete old values.
  db_delete('track_field_changes')->execute();

  $node_types = $form_state['values']['track_field_changes_node_types'];

  foreach ($node_types as $nt_key => $nt_value) {
    if ($nt_value) {

      if (isset($form_state['values'][$nt_key])) {
        $fields = $form_state['values'][$nt_key];
      }
      else {
        $fields = array();
      }

      foreach ($fields as $f_key => $f_value) {
        if ($f_value) {
          db_insert('track_field_changes')
            ->fields(array(
            'field_name' => $f_key,
            'entity_type' => 'node',
            'bundle' => $nt_key,
          ))
          ->execute();
        }
      }
    }
  }

  drupal_theme_rebuild();
}
